/* 
 * Copyright (C) 2004-2005 Jonathan Bindel
 * Copyright (C) 2006-2007 Eskil Bylund
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.Collections.Generic;

namespace DCSharp.Backend.Objects
{
	public class SearchEventArgs : EventArgs
	{
		private SearchInfo searchInfo;

		public SearchEventArgs(SearchInfo searchInfo)
		{
			this.searchInfo = searchInfo;
		}

		public SearchInfo SearchInfo
		{
			get { return searchInfo; }
		}
	}

	public enum SearchFileType
	{
		Any = 1,
		Audio,
		Package,
		Document,
		Executable,
		Image,
		Video,
		Directory
	}

	/// <summary>
	/// A search criteria.
	/// </summary>
	public class SearchInfo
	{
		private string[] keywords;
		private SearchFileType type;
		private long? maxSize;
		private long? minSize;
		private string tth;

		public SearchInfo(string[] keywords, SearchFileType type, long? maxSize,
			long? minSize)
		{
			this.keywords = keywords;
			this.type = type;
			this.maxSize = maxSize;
			this.minSize = minSize;
		}

		public SearchInfo(string tth)
		{
			this.tth = tth;
		}

		#region Properties

		public string[] Keywords
		{
			get { return keywords; }
		}

		public SearchFileType Type
		{
			get { return type; }
		}

		public long? MaxSize
		{
			get { return maxSize; }
		}

		public long? MinSize
		{
			get { return minSize; }
		}

		public string TTH
		{
			get { return tth; }
		}

		#endregion
	}
}
