/* 
 * Copyright (C) 2004-2005 Jonathan Bindel
 * Copyright (C) 2006-2007 Eskil Bylund
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

using System;
using System.Xml.Serialization;

using DCSharp.Backend.Connections;
using DCSharp.Backend.Managers;
using DCSharp.Xml;

namespace DCSharp.Backend.Objects
{
	public class SourceEventArgs : EventArgs
	{
		private SourceInfo source;

		public SourceEventArgs(SourceInfo source)
		{
			this.source = source;
		}

		public SourceInfo Source
		{
			get { return source; }
		}
	}

	public class SourceInfo
	{
		private User user;
		private bool isValid;
		private FileDownloadError error;

		private ConnectionMonitor monitor;
		private bool active;

		public SourceInfo(User user)
		{
			if (user == null)
			{
				throw new ArgumentNullException("user");
			}
			this.user = user;

			isValid = true;
		}

		#region Properties

		/// <summary>
		/// Gets the user the file is available from.
		/// </summary>
		public User User
		{
			get { return user; }
		}

		/// <summary>
		/// Gets whether or not this source is valid.
		/// </summary>
		public bool IsValid
		{
			get { return isValid; }
			internal set { isValid = value; }
		}

		public FileDownloadError Error
		{
			get { return error; }
			internal set { error = value; }
		}

		/// <summary>
		/// Gets whether or not this source is active.
		/// </summary>
		public bool Active
		{
			get { return active; }
			internal set { active = value; }
		}

		/// <summary>
		/// Gets the download speed if this source is active.
		/// </summary>
		public double DownloadSpeed
		{
			get { return monitor != null ? monitor.DownloadSpeed : 0; }
		}

		internal ConnectionMonitor Monitor
		{
			get { return monitor; }
			set { monitor = value; }
		}

		#endregion
	}
}
