/* 
 * Copyright (C) 2007 Eskil Bylund
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

namespace DCSharp
{
	/// <summary>
	/// The identity of a local user.
	/// </summary>
	public class LocalIdentity : Identity
	{
		private Uid pid;

		public LocalIdentity(Uid pid, string nick) :
			base(User.Create(Uid.CalculateCid(pid), nick), nick)
		{
			this.pid = pid;
		}

		/// <summary>
		/// Gets the Pid of the user.
		/// </summary>
		/// <value>The Pid of the user.</value>
		public Uid Pid
		{
			get { return pid; }
			set
			{
				pid = value;
				Cid = Uid.CalculateCid(pid);
			}
		}
	}
}
