/* 
 * Copyright (C) 2004-2005 Jonathan Bindel
 * Copyright (C) 2006-2007 Eskil Bylund
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

using System.Collections.Generic;
using System.Xml.Serialization;

namespace DCSharp.Xml
{
	/// <summary>
	/// Represents a directory in a <see cref="FileList"/>.
	/// </summary>
	public class DirectoryNode
	{
		private List<DirectoryNode> directories;
		private List<FileNode> files;
		private string name;

		public DirectoryNode(string name) : this()
		{
			this.name = name;
		}

		public DirectoryNode()
		{
			directories = new List<DirectoryNode>();
			files = new List<FileNode>();
		}

		#region Properties

		[XmlAttribute()]
		public string Name
		{
			get { return name; }
			set { name = value; }
		}

		[XmlElement("Directory")]
		public List<DirectoryNode> Directories
		{
			get { return directories; }
			set { directories = value; }
		}

		[XmlElement("File")]
		public List<FileNode> Files
		{
			get { return files; }
			set { files = value; }
		}

		#endregion

		#region Methods

		public long GetSize()
		{
			long total = 0;
			foreach (DirectoryNode directory in directories)
			{
				total += directory.GetSize();
			}
			foreach (FileNode file in files)
			{
				total += file.Size;
			}
			return total;
		}

		#endregion
	}
}
